==> unity-ads-4.10.0-sources.jar: com/unity3d/services/UnityAdsConstants.kt <==
package com.unity3d.services

import com.unity3d.ads.BuildConfig
import com.unity3d.services.UnityAdsConstants.Cache.CACHE_SCHEME
import com.unity3d.services.UnityAdsConstants.DefaultUrls.AD_ASSET_DOMAIN

object UnityAdsConstants {

    object Messages {
        const val MSG_UNITY_BASE = "[Unity Ads] "
        const val MSG_INTERNAL_ERROR = "Internal error"
    }

    object Timeout {
        const val INIT_TIMEOUT_MS = 10000L
    }

    object RequestPolicy {
        const val RETRY_MAX_DURATION = 15000
        const val RETRY_WAIT_BASE = 500
        const val RETRY_JITTER_PCT = 0.1f
        const val CONNECT_TIMEOUT_MS = 10000
        const val READ_TIMEOUT_MS = 10000
        const val WRITE_TIMEOUT_MS = 10000
        const val SHOULD_STORE_LOCALLY = false
    }

    object SharedFlow {
        const val REPLAY = 10
        const val EXTRA_CAPACITY = 10
    }

    object DefaultUrls {
        const val GATEWAY_URL = "https://gateway.unityads.unity3d.com/v1"
        const val WEBVIEW_DOMAIN = "config.unityads.unity3d.com"
        const val ASSET_DOMAIN = "cdn-creatives-cf-prd.acquire.unity3dusercontent.com"
        const val WEBVIEW_ASSET_PATH = "/unity-ads-sdk-webview/"
        const val AD_ASSET_PATH = "/"
        const val AD_CACHE_DOMAIN = "unity.ads.cache"
        const val AD_ASSET_DOMAIN = "unity.ads.asset"
        const val AD_MARKUP_URL = "https://gateway.unityads.unity3d.com/tools/convert_ad_response_to_ad_markup"
        const val AD_PLAYER_QUERY_PARAMS = "?platform=android&"
        const val CACHE_DIR_NAME = "UnityAdsCache"
    }

    object ClientInfo {
        const val SDK_VERSION = BuildConfig.VERSION_CODE
        const val SDK_VERSION_NAME = BuildConfig.VERSION_NAME
    }

    object OpenMeasurement {
        const val OM_PARTNER_NAME = "Unity3d"
        const val OM_PARTNER_VERSION = "1"
        const val OM_JS_FILENAME = "ad-viewer/omid-session-client-v1.js"
        const val OM_JS_URL = "$CACHE_SCHEME://$AD_ASSET_DOMAIN/$OM_JS_FILENAME"
    }

    object Cache {
        const val CACHE_SCHEME = "unity-ads-cache"
    }
}

==> unity-ads-4.11.2-sources.jar: com/unity3d/services/UnityAdsConstants.kt <==
package com.unity3d.services

import com.unity3d.ads.BuildConfig
import com.unity3d.services.UnityAdsConstants.Cache.CACHE_SCHEME
import com.unity3d.services.UnityAdsConstants.DefaultUrls.AD_ASSET_DOMAIN

object UnityAdsConstants {

    object Messages {
        const val MSG_UNITY_BASE = "[Unity Ads] "
        const val MSG_INTERNAL_ERROR = "Internal error"
    }

    object Timeout {
        const val INIT_TIMEOUT_MS = 10000L
        const val GET_TOKEN_TIMEOUT_MS = 5000L
    }

    object RequestPolicy {
        const val RETRY_MAX_DURATION = 20000
        const val RETRY_MAX_INTERVAL = 1000
        const val RETRY_SCALING_FACTOR = 2.0f
        const val RETRY_WAIT_BASE = 500
        const val RETRY_JITTER_PCT = 0.1f
        const val CONNECT_TIMEOUT_MS = 10000
        const val OVERALL_TIMEOUT_MS = 10000
        const val READ_TIMEOUT_MS = 10000
        const val WRITE_TIMEOUT_MS = 10000
        const val SHOULD_STORE_LOCALLY = false
    }

    object SharedFlow {
        const val REPLAY = 10
        const val EXTRA_CAPACITY = 10
    }

    object DefaultUrls {
        const val GATEWAY_URL = "https://gateway.unityads.unity3d.com/v1"
        const val WEBVIEW_DOMAIN = "config.unityads.unity3d.com"
        const val ASSET_DOMAIN = "cdn-creatives-cf-prd.acquire.unity3dusercontent.com"
        const val WEBVIEW_ASSET_PATH = "/unity-ads-sdk-webview/"
        const val AD_ASSET_PATH = "/"
        const val AD_CACHE_DOMAIN = "unity.ads.cache"
        const val AD_ASSET_DOMAIN = "unity.ads.asset"
        const val AD_MARKUP_URL = "https://gateway.unityads.unity3d.com/tools/convert_ad_response_to_ad_markup"
        const val AD_PLAYER_QUERY_PARAMS = "?platform=android&"
        const val CACHE_DIR_NAME = "UnityAdsCache"
    }

    object ClientInfo {
        const val SDK_VERSION = BuildConfig.VERSION_CODE
        const val SDK_VERSION_NAME = BuildConfig.VERSION_NAME
    }

    object OpenMeasurement {
        const val OM_PARTNER_NAME = "Unity3d"
        const val OM_PARTNER_VERSION = "1"
        const val OM_JS_SESSION_FILENAME = "ad-viewer/omid-session-client-v1.js"
        const val OM_JS_SERVICE_FILENAME = "ad-viewer/omsdk-v1.js"
        const val OM_JS_URL_SESSION = "$CACHE_SCHEME://$AD_ASSET_DOMAIN/$OM_JS_SESSION_FILENAME"
        const val OM_JS_URL_SERVICE = "$CACHE_SCHEME://$AD_ASSET_DOMAIN/$OM_JS_SERVICE_FILENAME"
        const val OM_SESSION_FINISH_DELAY_MS = 1000L
    }

    object Cache {
        const val CACHE_SCHEME = "unity-ads-cache"
    }

    object AdOperations {
        const val LOAD_TIMEOUT_MS = 30000
        const val SHOW_TIMEOUT_MS = 10000
        const val GET_TOKEN_TIMEOUT_MS = 5000
    }
}
